==> mui-extension-4.1.3.tgz: package/lib/Autocomplete/Autocomplete.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { Box, Checkbox, Icon, Input, InputAdornment, Menu } from '@mui/material';
import { combineSx, makeSx } from '../_utils/common';
var sx = makeSx({
    menu_head: {
        mt: -1,
        borderBottom: function (t) { return "1px solid ".concat(t.palette.divider); },
        display: 'flex',
        alignItems: 'center',
        minHeight: 48,
    },
    menu_headWithCb: {
        pl: 0,
    },
    menu_input: {
        background: 'none',
        border: 'none',
        width: '100%',
        height: 30,
        fontSize: '1rem',
        color: function (t) { return t.palette.text.primary; },
    },
    menu_items: {
        maxHeight: 300,
        overflowY: 'auto',
        minWidth: 220,
    },
    adornment: {
        height: 20,
        color: function (t) { return t.palette.text.secondary; },
        verticalAlign: 'top',
    }
});
export var Autocomplete = function (_a) {
    var value = _a.value, multiple = _a.multiple, searchLabel = _a.searchLabel, readonly = _a.readonly, children = _a.children, onChange = _a.onChange;
    var _b = React.useState(null), anchorEl = _b[0], setAnchorEl = _b[1];
    var _c = React.useState(undefined), filter = _c[0], setFilter = _c[1];
    var $input = undefined;
    var open = function (event) { return setAnchorEl(event.currentTarget); };
    var close = function () {
        setAnchorEl(null);
        setFilter('');
    };
    var handleChange = function (changedValue) {
        var getValue = function () {
            if (multiple) {
                return ((value === null || value === void 0 ? void 0 : value.indexOf(changedValue)) === -1) ? value.concat(changedValue) : value.filter(function (_) { return _ !== changedValue; });
            }
            else {
                close();
                return value !== changedValue ? changedValue : '';
            }
        };
        onChange(getValue());
    };
    var getFilteredChildren = function () {
        if (!children)
            return [];
        var items = React.Children.map(children, function (_) { return _; });
        return (filter && filter !== '')
            ? items.filter(function (_) { return _.props.value.toLowerCase().indexOf(filter.toLowerCase()) !== -1; })
            : items;
    };
    var selectAll = function (event, checked) {
        if (children) {
            var values = checked ? React.Children.map(children, function (_) { return _.props.value; }) : [];
            onChange(values);
        }
    };
    var optionsCount = React.Children.count(children);
    var filteredChildren = getFilteredChildren();
    return (React.createElement(React.Fragment, null,
        React.createElement(Input, { onClick: open, value: multiple ? value && value.join(', ') : value, disabled: readonly, inputRef: function (n) { return $input = n !== null && n !== void 0 ? n : undefined; }, endAdornment: React.createElement(InputAdornment, { position: "end" },
                React.createElement(Icon, { sx: sx.adornment }, "arrow_drop_down")) }),
        React.createElement(Menu, { anchorEl: anchorEl, open: !!anchorEl, onClose: close },
            React.createElement(Box, { sx: combineSx(sx.menu_head, multiple && sx.menu_headWithCb) },
                multiple &&
                    React.createElement(Checkbox, { checked: !!value && value.length === optionsCount, onChange: selectAll, indeterminate: !!value && (value.length > 0 && value.length < optionsCount), disabled: readonly }),
                React.createElement(Box, { component: "input", autoFocus: true, sx: sx.menu_input, placeholder: searchLabel, style: !multiple ? { marginLeft: 12 } : {}, onChange: function (e) { return setFilter(e.target.value); } })),
            React.createElement(Box, { sx: sx.menu_items, style: { width: $input === null || $input === void 0 ? void 0 : $input.clientWidth } }, filteredChildren.map(function (_) {
                return React.cloneElement(_, __assign(__assign({}, _.props), { multiple: multiple, checked: !!value && value.indexOf(_.props.value) !== -1, onClick: handleChange }));
            })))));
};

==> mui-extension-4.2.0.tgz: package/lib/Autocomplete/Autocomplete.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { Box, Checkbox, Icon, Input, InputAdornment, Menu } from '@mui/material';
import { makeSx } from '../_utils/common';
var sx = makeSx({
    menu_head: {
        mt: -1,
        borderBottom: function (t) { return "1px solid " + t.palette.divider; },
        display: 'flex',
        alignItems: 'center',
        minHeight: 48,
    },
    menu_headWithCb: {
        pl: 0,
    },
    menu_input: {
        background: 'none',
        border: 'none',
        width: '100%',
        height: 30,
        fontSize: '1em',
        color: function (t) { return t.palette.text.primary; },
    },
    menu_items: {
        maxHeight: 300,
        overflowY: 'auto',
        minWidth: 220,
    },
    adornment: {
        height: 20,
        color: function (t) { return t.palette.text.secondary; },
        verticalAlign: 'top',
    }
});
export var Autocomplete = function (_a) {
    var value = _a.value, multiple = _a.multiple, searchLabel = _a.searchLabel, readonly = _a.readonly, children = _a.children, onChange = _a.onChange;
    var _b = React.useState(null), anchorEl = _b[0], setAnchorEl = _b[1];
    var _c = React.useState(undefined), filter = _c[0], setFilter = _c[1];
    var $input = undefined;
    var open = function (event) { return setAnchorEl(event.currentTarget); };
    var close = function () {
        setAnchorEl(null);
        setFilter('');
    };
    var handleChange = function (changedValue) {
        var getValue = function () {
            if (multiple) {
                return ((value === null || value === void 0 ? void 0 : value.indexOf(changedValue)) === -1) ? value.concat(changedValue) : value.filter(function (_) { return _ !== changedValue; });
            }
            else {
                close();
                return value !== changedValue ? changedValue : '';
            }
        };
        onChange(getValue());
    };
    var getFilteredChildren = function () {
        if (!children)
            return [];
        var items = React.Children.map(children, function (_) { return _; });
        return (filter && filter !== '')
            ? items.filter(function (_) { return _.props.value.toLowerCase().indexOf(filter.toLowerCase()) !== -1; })
            : items;
    };
    var selectAll = function (event, checked) {
        if (children) {
            var values = checked ? React.Children.map(children, function (_) { return _.props.value; }) : [];
            onChange(values);
        }
    };
    var optionsCount = React.Children.count(children);
    var filteredChildren = getFilteredChildren();
    return (React.createElement(React.Fragment, null,
        React.createElement(Input, { onClick: open, value: multiple ? value && value.join(', ') : value, disabled: readonly, inputRef: function (n) { return $input = n !== null && n !== void 0 ? n : undefined; }, endAdornment: React.createElement(InputAdornment, { position: "end" },
                React.createElement(Icon, { sx: sx.adornment }, "arrow_drop_down")) }),
        React.createElement(Menu, { anchorEl: anchorEl, open: !!anchorEl, onClose: close },
            React.createElement(Box, { sx: __assign(__assign({}, sx.menu_head), multiple && sx.menu_headWithCb) },
                multiple &&
                    React.createElement(Checkbox, { checked: !!value && value.length === optionsCount, onChange: selectAll, indeterminate: !!value && (value.length > 0 && value.length < optionsCount), disabled: readonly }),
                React.createElement(Box, { component: "input", autoFocus: true, sx: sx.menu_input, placeholder: searchLabel, style: !multiple ? { marginLeft: 12 } : {}, onChange: function (e) { return setFilter(e.target.value); } })),
            React.createElement(Box, { sx: sx.menu_items, style: { width: $input === null || $input === void 0 ? void 0 : $input.clientWidth } }, filteredChildren.map(function (_) {
                return React.cloneElement(_, __assign(__assign({}, _.props), { multiple: multiple, checked: !!value && value.indexOf(_.props.value) !== -1, onClick: handleChange }));
            })))));
};
